# Boron
Boron is a framework for simple http applications. I did not intend to write it, but
created it while writing [ghh](github.com/schlueter/ghh) as a way to isolate the http
logic from the business logic of that application.

## Installation

For development:

    git clone https://github.com/schlueter/boron.git
    cd boron
    pip install .

## Testing
This project uses [tox](https://tox.readthedocs.io/) to manage testing.
